Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Identity ¶
type Identity interface {
ExpiresAt() time.Time
GetIdentifier() *IdentityIdentifier
GetMSPIdentifier() string
Validate() error
//匿名
Anonymous() bool
//使用作为引用的identify来给消息进行签名
Verify(msg []byte, sig []byte) error
//将签名转化为字符串
Serialize() ([]byte, error)
}
Identity 接口 定义操作包含 证书。 提供签名认证。
type IdentityIdentifier ¶
type IdentityIdentifier struct {
// The identifier of the associated membership service provider
Mspid string
// The identifier for an identity within a provider
Id string
}
IdentityIdentifier is a holder for the identifier of a specific identity, naturally namespaced, by its provider identifier.
type ProviderType ¶
type ProviderType int
证书提供者的类型
const ( FABRIC ProviderType = iota // MSP is of FABRIC type IDEMIX // MSP is of IDEMIX type OTHER // MSP is of OTHER TYPE )
Click to show internal directories.
Click to hide internal directories.